/* Generated by ./dbus-analyze-functions.py.  Do not edit! */
PurpleAccount* purple_accounts_find_any(const char *name, const char *protocol) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountsFindAny", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, protocol,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

PurpleAccount* purple_accounts_find_connected(const char *name, const char *protocol) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountsFindConnected", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, protocol,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

gboolean PURPLE_BLIST_NODE_IS_CHAT(const PurpleBlistNode *node) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeIsChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_BLIST_NODE_IS_BUDDY(const PurpleBlistNode *node) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeIsBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_BLIST_NODE_IS_CONTACT(const PurpleBlistNode *node) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeIsContact", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_BLIST_NODE_IS_GROUP(const PurpleBlistNode *node) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeIsGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_BUDDY_IS_ONLINE(const PurpleBuddy *buddy) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIsOnline", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_BLIST_NODE_HAS_FLAG(const PurpleBlistNode *node, int flags) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeHasFlag", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_INT, flags,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_BLIST_NODE_SHOULD_SAVE(const PurpleBlistNode *node) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeShouldSave", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_CONNECTION_IS_CONNECTED(const PurpleConnection *connection) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionIsConnected", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(connection),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean PURPLE_CONNECTION_IS_VALID(const PurpleConnection *connection) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionIsValid", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(connection),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConvIm* PURPLE_CONV_IM(const PurpleConversation *conversation) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvIm", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conversation),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConvIm*) GINT_TO_POINTER(RESULT_ID);
}

PurpleConvIm* PURPLE_CONV_CHAT(const PurpleConversation *conversation) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conversation),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConvIm*) GINT_TO_POINTER(RESULT_ID);
}

PurpleAccount* purple_account_new(const char *username, const char *protocol_id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountNew", NULL,
	G_TYPE_STRING, username,  	G_TYPE_STRING, protocol_id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

void purple_account_destroy(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_connect(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountConnect", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_register(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRegister", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_disconnect(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountDisconnect", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_notify_added(const PurpleAccount *account, const char *remote_user, const char *id, const char *alias, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountNotifyAdded", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, remote_user,  	G_TYPE_STRING, id,  	G_TYPE_STRING, alias,  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_request_add(const PurpleAccount *account, const char *remote_user, const char *id, const char *alias, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRequestAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, remote_user,  	G_TYPE_STRING, id,  	G_TYPE_STRING, alias,  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_request_close_with_account(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRequestCloseWithAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_request_close(const void *ui_handle_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRequestClose", NULL,
	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_request_change_password(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRequestChangePassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_request_change_user_info(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRequestChangeUserInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_username(const PurpleAccount *account, const char *username) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetUsername", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, username,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_password(const PurpleAccount *account, const char *password) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetPassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, password,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_alias(const PurpleAccount *account, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_user_info(const PurpleAccount *account, const char *user_info) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetUserInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, user_info,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_buddy_icon_path(const PurpleAccount *account, const char *path) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetBuddyIconPath", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, path,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_protocol_id(const PurpleAccount *account, const char *protocol_id) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetProtocolId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, protocol_id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_connection(const PurpleAccount *account, const PurpleConnection *gc) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetConnection", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_remember_password(const PurpleAccount *account, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetRememberPassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_check_mail(const PurpleAccount *account, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetCheckMail", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_enabled(const PurpleAccount *account, const char *ui, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetEnabled", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_proxy_info(const PurpleAccount *account, const PurpleProxyInfo *info) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetProxyInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(info),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_privacy_type(const PurpleAccount *account, PurplePrivacyType privacy_type) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetPrivacyType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, privacy_type,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_status_types(const PurpleAccount *account, const GList *status_types_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetStatusTypes", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_status_list(const PurpleAccount *account, const char *status_id, gboolean active, const GList *attrs_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetStatusList", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, status_id,  	G_TYPE_INT, active,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_account_get_silence_suppression(const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetSilenceSuppression", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_account_set_silence_suppression(const PurpleAccount *account, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetSilenceSuppression", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_clear_settings(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountClearSettings", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_remove_setting(const PurpleAccount *account, const char *setting) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRemoveSetting", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, setting,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_int(const PurpleAccount *account, const char *name, int value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_string(const PurpleAccount *account, const char *name, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_bool(const PurpleAccount *account, const char *name, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetBool", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_ui_int(const PurpleAccount *account, const char *ui, const char *name, int value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetUiInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_ui_string(const PurpleAccount *account, const char *ui, const char *name, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetUiString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_STRING, name,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_set_ui_bool(const PurpleAccount *account, const char *ui, const char *name, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountSetUiBool", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_account_is_connected(const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountIsConnected", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_is_connecting(const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountIsConnecting", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_is_disconnected(const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountIsDisconnected", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_username(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetUsername", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_password(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetPassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_alias(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_user_info(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetUserInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_buddy_icon_path(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetBuddyIconPath", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_protocol_id(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetProtocolId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_protocol_name(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetProtocolName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConnection* purple_account_get_connection(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetConnection", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConnection*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_account_get_name_for_display(const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetNameForDisplay", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_get_remember_password(const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetRememberPassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_get_check_mail(const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetCheckMail", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_get_enabled(const PurpleAccount *account, const char *ui) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetEnabled", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleProxyInfo* purple_account_get_proxy_info(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetProxyInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleProxyInfo*) GINT_TO_POINTER(RESULT_ID);
}

PurplePrivacyType purple_account_get_privacy_type(const PurpleAccount *account) {
PurplePrivacyType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetPrivacyType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStatus* purple_account_get_active_status(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetActiveStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatus* purple_account_get_status(const PurpleAccount *account, const char *status_id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, status_id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatusType* purple_account_get_status_type(const PurpleAccount *account, const char *id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetStatusType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatusType* purple_account_get_status_type_with_primitive(const PurpleAccount *account, PurpleStatusPrimitive primitive) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetStatusTypeWithPrimitive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, primitive,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

PurplePresence* purple_account_get_presence(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetPresence", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_account_is_status_active(const PurpleAccount *account, const char *status_id) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountIsStatusActive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, status_id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_account_get_status_types(const PurpleAccount *account) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetStatusTypes", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

int purple_account_get_int(const PurpleAccount *account, const char *name, int default_value) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, default_value,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_string(const PurpleAccount *account, const char *name, const char *default_value) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_STRING, default_value,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_get_bool(const PurpleAccount *account, const char *name, gboolean default_value) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetBool", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, default_value,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_account_get_ui_int(const PurpleAccount *account, const char *ui, const char *name, int default_value) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetUiInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_STRING, name,  	G_TYPE_INT, default_value,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_account_get_ui_string(const PurpleAccount *account, const char *ui, const char *name, const char *default_value) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetUiString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_STRING, name,  	G_TYPE_STRING, default_value,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_account_get_ui_bool(const PurpleAccount *account, const char *ui, const char *name, gboolean default_value) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetUiBool", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ui,  	G_TYPE_STRING, name,  	G_TYPE_INT, default_value,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleLog* purple_account_get_log(const PurpleAccount *account, gboolean create) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetLog", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, create,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleLog*) GINT_TO_POINTER(RESULT_ID);
}

void purple_account_destroy_log(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountDestroyLog", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_add_buddy(const PurpleAccount *account, const PurpleBuddy *buddy) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountAddBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_add_buddy_with_invite(const PurpleAccount *account, const PurpleBuddy *buddy, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountAddBuddyWithInvite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_add_buddies(const PurpleAccount *account, const GList *buddies_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountAddBuddies", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_add_buddies_with_invite(const PurpleAccount *account, const GList *buddies_NULL, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountAddBuddiesWithInvite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, 0,  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_remove_buddy(const PurpleAccount *account, const PurpleBuddy *buddy, const PurpleGroup *group) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRemoveBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_remove_buddies(const PurpleAccount *account, const GList *buddies_NULL, const GList *groups_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRemoveBuddies", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, 0,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_remove_group(const PurpleAccount *account, const PurpleGroup *group) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountRemoveGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_account_change_password(const PurpleAccount *account, const char *orig_pw, const char *new_pw) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountChangePassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, orig_pw,  	G_TYPE_STRING, new_pw,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_account_supports_offline_message(const PurpleAccount *account, const PurpleBuddy *buddy) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountSupportsOfflineMessage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConnectionErrorInfo* purple_account_get_current_error(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountGetCurrentError", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConnectionErrorInfo*) GINT_TO_POINTER(RESULT_ID);
}

void purple_account_clear_current_error(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountClearCurrentError", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_accounts_add(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_accounts_remove(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsRemove", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_accounts_delete(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsDelete", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_accounts_reorder(const PurpleAccount *account, gint new_index) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsReorder", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, new_index,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_accounts_get_all(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleAccountsGetAll", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_accounts_get_all_active(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleAccountsGetAllActive", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleAccount* purple_accounts_find(const char *name, const char *protocol) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountsFind", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, protocol,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

void purple_accounts_restore_current_statuses(void) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsRestoreCurrentStatuses", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_accounts_set_ui_ops(const PurpleAccountUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleAccountUiOps* purple_accounts_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountsGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccountUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_account_prefs_set_ui_ops(const PurpleAccountPrefsUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountPrefsSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleAccountPrefsUiOps* purple_account_prefs_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAccountPrefsGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccountPrefsUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_accounts_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_accounts_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleAccountsUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddyList* purple_blist_new(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNew", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyList*) GINT_TO_POINTER(RESULT_ID);
}

void purple_set_blist(const PurpleBuddyList *blist) {
dbus_g_proxy_call(purple_proxy, "PurpleSetBlist", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(blist),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddyList* purple_get_blist(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleGetBlist", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyList*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBlistNode* purple_blist_get_root(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistGetRoot", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistNode*) GINT_TO_POINTER(RESULT_ID);
}

GSList* purple_blist_get_buddies(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleBlistGetBuddies", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_gslist(RESULT);
}

PurpleBlistNode* purple_blist_node_next(const PurpleBlistNode *node, gboolean offline) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeNext", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_INT, offline,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistNode*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBlistNode* purple_blist_node_get_parent(const PurpleBlistNode *node) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetParent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistNode*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBlistNode* purple_blist_node_get_first_child(const PurpleBlistNode *node) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetFirstChild", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistNode*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBlistNode* purple_blist_node_get_sibling_next(const PurpleBlistNode *node) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetSiblingNext", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistNode*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBlistNode* purple_blist_node_get_sibling_prev(const PurpleBlistNode *node) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetSiblingPrev", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistNode*) GINT_TO_POINTER(RESULT_ID);
}

void purple_blist_show(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistShow", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_destroy(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistDestroy", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_set_visible(gboolean show) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistSetVisible", NULL,
	G_TYPE_INT, show,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_update_buddy_status(const PurpleBuddy *buddy, const PurpleStatus *old_status) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistUpdateBuddyStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_INT, GPOINTER_TO_INT(old_status),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_update_node_icon(const PurpleBlistNode *node) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistUpdateNodeIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_update_buddy_icon(const PurpleBuddy *buddy) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistUpdateBuddyIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_rename_buddy(const PurpleBuddy *buddy, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRenameBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_alias_contact(const PurpleContact *contact, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAliasContact", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_alias_buddy(const PurpleBuddy *buddy, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAliasBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_server_alias_buddy(const PurpleBuddy *buddy, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistServerAliasBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_alias_chat(const PurpleChat *chat, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAliasChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_rename_group(const PurpleGroup *group, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRenameGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleChat* purple_chat_new(const PurpleAccount *account, const char *alias, const GHashTable *components) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleChatNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, alias,  	dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), components,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleChat*) GINT_TO_POINTER(RESULT_ID);
}

void purple_chat_destroy(const PurpleChat *chat) {
dbus_g_proxy_call(purple_proxy, "PurpleChatDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_add_chat(const PurpleChat *chat, const PurpleGroup *group, const PurpleBlistNode *node) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAddChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddy* purple_buddy_new(const PurpleAccount *account, const char *name, const char *alias) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddy*) GINT_TO_POINTER(RESULT_ID);
}

void purple_buddy_destroy(const PurpleBuddy *buddy) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_buddy_set_icon(const PurpleBuddy *buddy, const PurpleBuddyIcon *icon) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddySetIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleAccount* purple_buddy_get_account(const PurpleBuddy *buddy) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_buddy_get_name(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleBuddyIcon* purple_buddy_get_icon(const PurpleBuddy *buddy) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyIcon*) GINT_TO_POINTER(RESULT_ID);
}

PurpleContact* purple_buddy_get_contact(const PurpleBuddy *buddy) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetContact", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleContact*) GINT_TO_POINTER(RESULT_ID);
}

PurplePresence* purple_buddy_get_presence(const PurpleBuddy *buddy) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetPresence", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

PurpleMediaCaps purple_buddy_get_media_caps(const PurpleBuddy *buddy) {
PurpleMediaCaps RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetMediaCaps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_buddy_set_media_caps(const PurpleBuddy *buddy, PurpleMediaCaps media_caps) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddySetMediaCaps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_INT, media_caps,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_add_buddy(const PurpleBuddy *buddy, const PurpleContact *contact, const PurpleGroup *group, const PurpleBlistNode *node) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAddBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  	G_TYPE_INT, GPOINTER_TO_INT(contact),  	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleGroup* purple_group_new(const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleGroupNew", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleGroup*) GINT_TO_POINTER(RESULT_ID);
}

void purple_group_destroy(const PurpleGroup *group) {
dbus_g_proxy_call(purple_proxy, "PurpleGroupDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_add_group(const PurpleGroup *group, const PurpleBlistNode *node) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAddGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleContact* purple_contact_new(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleContactNew", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleContact*) GINT_TO_POINTER(RESULT_ID);
}

void purple_contact_destroy(const PurpleContact *contact) {
dbus_g_proxy_call(purple_proxy, "PurpleContactDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleGroup* purple_contact_get_group(const PurpleContact *contact) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleContactGetGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleGroup*) GINT_TO_POINTER(RESULT_ID);
}

void purple_blist_add_contact(const PurpleContact *contact, const PurpleGroup *group, const PurpleBlistNode *node) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAddContact", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_merge_contact(const PurpleContact *source, const PurpleBlistNode *node) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistMergeContact", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(source),  	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddy* purple_contact_get_priority_buddy(const PurpleContact *contact) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleContactGetPriorityBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddy*) GINT_TO_POINTER(RESULT_ID);
}

void purple_contact_set_alias(const PurpleContact *contact, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleContactSetAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_contact_get_alias(const PurpleContact *contact) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleContactGetAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_contact_on_account(const PurpleContact *contact, const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleContactOnAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_contact_invalidate_priority_buddy(const PurpleContact *contact) {
dbus_g_proxy_call(purple_proxy, "PurpleContactInvalidatePriorityBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_remove_buddy(const PurpleBuddy *buddy) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRemoveBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_remove_contact(const PurpleContact *contact) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRemoveContact", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_remove_chat(const PurpleChat *chat) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRemoveChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_remove_group(const PurpleGroup *group) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRemoveGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_buddy_get_alias_only(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetAliasOnly", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_get_server_alias(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetServerAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_get_contact_alias(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetContactAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_get_local_alias(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetLocalAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_get_alias(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_get_local_buddy_alias(const PurpleBuddy *buddy) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetLocalBuddyAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_chat_get_name(const PurpleChat *chat) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleChatGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleBuddy* purple_find_buddy(const PurpleAccount *account, const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleFindBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddy*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBuddy* purple_find_buddy_in_group(const PurpleAccount *account, const char *name, const PurpleGroup *group) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleFindBuddyInGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddy*) GINT_TO_POINTER(RESULT_ID);
}

GSList* purple_find_buddies(const PurpleAccount *account, const char *name) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleFindBuddies", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_gslist(RESULT);
}

PurpleGroup* purple_find_group(const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleFindGroup", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleGroup*) GINT_TO_POINTER(RESULT_ID);
}

PurpleChat* purple_blist_find_chat(const PurpleAccount *account, const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistFindChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleChat*) GINT_TO_POINTER(RESULT_ID);
}

PurpleGroup* purple_chat_get_group(const PurpleChat *chat) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleChatGetGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleGroup*) GINT_TO_POINTER(RESULT_ID);
}

PurpleAccount* purple_chat_get_account(const PurpleChat *chat) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleChatGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

PurpleGroup* purple_buddy_get_group(const PurpleBuddy *buddy) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyGetGroup", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleGroup*) GINT_TO_POINTER(RESULT_ID);
}

GSList* purple_group_get_accounts(const PurpleGroup *g) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleGroupGetAccounts", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(g),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_gslist(RESULT);
}

gboolean purple_group_on_account(const PurpleGroup *g, const PurpleAccount *account) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleGroupOnAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(g),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_group_get_name(const PurpleGroup *group) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleGroupGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_blist_add_account(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistAddAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_remove_account(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRemoveAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

int purple_blist_get_group_size(const PurpleGroup *group, gboolean offline) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistGetGroupSize", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_INT, offline,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_blist_get_group_online_count(const PurpleGroup *group) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistGetGroupOnlineCount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(group),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_blist_load(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistLoad", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_schedule_save(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistScheduleSave", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_request_add_buddy(const PurpleAccount *account, const char *username, const char *group, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRequestAddBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, username,  	G_TYPE_STRING, group,  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_request_add_chat(const PurpleAccount *account, const PurpleGroup *group, const char *alias, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRequestAddChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(group),  	G_TYPE_STRING, alias,  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_request_add_group(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistRequestAddGroup", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_node_set_bool(const PurpleBlistNode *node, const char *key, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeSetBool", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_blist_node_get_bool(const PurpleBlistNode *node, const char *key) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetBool", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_blist_node_set_int(const PurpleBlistNode *node, const char *key, int value) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeSetInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

int purple_blist_node_get_int(const PurpleBlistNode *node, const char *key) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_blist_node_set_string(const PurpleBlistNode *node, const char *key, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeSetString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_blist_node_get_string(const PurpleBlistNode *node, const char *key) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_blist_node_remove_setting(const PurpleBlistNode *node, const char *key) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeRemoveSetting", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, key,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_node_set_flags(const PurpleBlistNode *node, PurpleBlistNodeFlags flags) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeSetFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_INT, flags,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBlistNodeFlags purple_blist_node_get_flags(const PurpleBlistNode *node) {
PurpleBlistNodeFlags RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleBlistNodeType purple_blist_node_get_type(const PurpleBlistNode *node) {
PurpleBlistNodeType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_blist_node_get_extended_menu(const PurpleBlistNode *n) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleBlistNodeGetExtendedMenu", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(n),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_blist_set_ui_ops(const PurpleBlistUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBlistUiOps* purple_blist_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBlistGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBlistUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_blist_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_blist_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBlistUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddyIcon* purple_buddy_icon_new(const PurpleAccount *account, const char *username, const void *icon_data_NULL, size_t icon_len, const char *checksum) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, username,  	G_TYPE_INT, 0,  	G_TYPE_INT, icon_len,  	G_TYPE_STRING, checksum,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyIcon*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBuddyIcon* purple_buddy_icon_ref(const PurpleBuddyIcon *icon) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconRef", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyIcon*) GINT_TO_POINTER(RESULT_ID);
}

PurpleBuddyIcon* purple_buddy_icon_unref(const PurpleBuddyIcon *icon) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconUnref", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyIcon*) GINT_TO_POINTER(RESULT_ID);
}

void purple_buddy_icon_update(const PurpleBuddyIcon *icon) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconUpdate", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_buddy_icon_set_data(const PurpleBuddyIcon *icon, const guchar *data_NULL, size_t len, const char *checksum) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconSetData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  	G_TYPE_INT, 0,  	G_TYPE_INT, len,  	G_TYPE_STRING, checksum,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleAccount* purple_buddy_icon_get_account(const PurpleBuddyIcon *icon) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_buddy_icon_get_username(const PurpleBuddyIcon *icon) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconGetUsername", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_icon_get_checksum(const PurpleBuddyIcon *icon) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconGetChecksum", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_icon_get_extension(const PurpleBuddyIcon *icon) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconGetExtension", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_buddy_icon_get_full_path(const PurpleBuddyIcon *icon) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconGetFullPath", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_buddy_icons_set_for_user(const PurpleAccount *account, const char *username, const void *icon_data_NULL, size_t icon_len, const char *checksum) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsSetForUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, username,  	G_TYPE_INT, 0,  	G_TYPE_INT, icon_len,  	G_TYPE_STRING, checksum,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddyIcon* purple_buddy_icons_find(const PurpleAccount *account, const char *username) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsFind", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, username,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyIcon*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStoredImage* purple_buddy_icons_find_account_icon(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsFindAccountIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStoredImage* purple_buddy_icons_set_account_icon(const PurpleAccount *account, const guchar *icon_data_NULL, size_t icon_len) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsSetAccountIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, 0,  	G_TYPE_INT, icon_len,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

time_t purple_buddy_icons_get_account_icon_timestamp(const PurpleAccount *account) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsGetAccountIconTimestamp", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_buddy_icons_node_has_custom_icon(const PurpleBlistNode *node) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsNodeHasCustomIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStoredImage* purple_buddy_icons_node_find_custom_icon(const PurpleBlistNode *node) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsNodeFindCustomIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStoredImage* purple_buddy_icons_node_set_custom_icon(const PurpleBlistNode *node, const guchar *icon_data_NULL, size_t icon_len) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsNodeSetCustomIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_INT, 0,  	G_TYPE_INT, icon_len,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStoredImage* purple_buddy_icons_node_set_custom_icon_from_file(const PurpleBlistNode *node, const char *filename) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsNodeSetCustomIconFromFile", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, filename,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_buddy_icons_has_custom_icon(const PurpleContact *contact) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsHasCustomIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStoredImage* purple_buddy_icons_find_custom_icon(const PurpleContact *contact) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsFindCustomIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStoredImage* purple_buddy_icons_set_custom_icon(const PurpleContact *contact, const guchar *icon_data_NULL, size_t icon_len) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsSetCustomIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(contact),  	G_TYPE_INT, 0,  	G_TYPE_INT, icon_len,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

void purple_buddy_icons_set_caching(gboolean caching) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsSetCaching", NULL,
	G_TYPE_INT, caching,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_buddy_icons_is_caching(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsIsCaching", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_buddy_icons_set_cache_dir(const char *cache_dir) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsSetCacheDir", NULL,
	G_TYPE_STRING, cache_dir,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_buddy_icons_get_cache_dir(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsGetCacheDir", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_buddy_icons_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_buddy_icons_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconsUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_buddy_icon_get_scale_size(const PurpleBuddyIconSpec *spec, const int *width_NULL, const int *height_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleBuddyIconGetScaleSize", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(spec),  	G_TYPE_INT, 0,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_new(const PurpleAccount *account, gboolean regist, const char *password) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, regist,  	G_TYPE_STRING, password,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_destroy(const PurpleConnection *gc) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_set_state(const PurpleConnection *gc, PurpleConnectionState state) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionSetState", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, state,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_set_account(const PurpleConnection *gc, const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionSetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_set_display_name(const PurpleConnection *gc, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionSetDisplayName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_set_protocol_data(const PurpleConnection *connection, const void *proto_data_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionSetProtocolData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(connection),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConnectionState purple_connection_get_state(const PurpleConnection *gc) {
PurpleConnectionState RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionGetState", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleAccount* purple_connection_get_account(const PurpleConnection *gc) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

PurplePlugin* purple_connection_get_prpl(const PurpleConnection *gc) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionGetPrpl", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePlugin*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_connection_get_password(const PurpleConnection *gc) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionGetPassword", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_connection_get_display_name(const PurpleConnection *gc) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionGetDisplayName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_connection_update_progress(const PurpleConnection *gc, const char *text, size_t step, size_t count) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionUpdateProgress", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, text,  	G_TYPE_INT, step,  	G_TYPE_INT, count,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_notice(const PurpleConnection *gc, const char *text) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionNotice", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, text,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_error(const PurpleConnection *gc, const char *reason) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionError", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, reason,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_error_reason(const PurpleConnection *gc, PurpleConnectionError reason, const char *description) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionErrorReason", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, reason,  	G_TYPE_STRING, description,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connection_ssl_error(const PurpleConnection *gc, PurpleSslErrorType ssl_error) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionSslError", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, ssl_error,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_connection_error_is_fatal(PurpleConnectionError reason) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionErrorIsFatal", NULL,
	G_TYPE_INT, reason,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_connections_disconnect_all(void) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsDisconnectAll", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_connections_get_all(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsGetAll", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_connections_get_connecting(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsGetConnecting", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_connections_set_ui_ops(const PurpleConnectionUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConnectionUiOps* purple_connections_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConnectionUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_connections_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_connections_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleConnectionsUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConversation* purple_conversation_new(PurpleConversationType type, const PurpleAccount *account, const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationNew", NULL,
	G_TYPE_INT, type,  	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conversation_destroy(const PurpleConversation *conv) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conversation_present(const PurpleConversation *conv) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationPresent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConversationType purple_conversation_get_type(const PurpleConversation *conv) {
PurpleConversationType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conversation_set_ui_ops(const PurpleConversation *conv, const PurpleConversationUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conversations_set_ui_ops(const PurpleConversationUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationsSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConversationUiOps* purple_conversation_get_ui_ops(const PurpleConversation *conv) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversationUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conversation_set_account(const PurpleConversation *conv, const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationSetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleAccount* purple_conversation_get_account(const PurpleConversation *conv) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

PurpleConnection* purple_conversation_get_gc(const PurpleConversation *conv) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetGc", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConnection*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conversation_set_title(const PurpleConversation *conv, const char *title) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationSetTitle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_STRING, title,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_conversation_get_title(const PurpleConversation *conv) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetTitle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conversation_autoset_title(const PurpleConversation *conv) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationAutosetTitle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conversation_set_name(const PurpleConversation *conv, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationSetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_conversation_get_name(const PurpleConversation *conv) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_conv_chat_cb_get_attribute(const PurpleConvChatBuddy *cb, const char *key) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbGetAttribute", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(cb),  	G_TYPE_STRING, key,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_conv_chat_cb_get_attribute_keys(const PurpleConvChatBuddy *cb) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbGetAttributeKeys", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(cb),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_conv_chat_cb_set_attribute(const PurpleConvChat *chat, const PurpleConvChatBuddy *cb, const char *key, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbSetAttribute", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, GPOINTER_TO_INT(cb),  	G_TYPE_STRING, key,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_cb_set_attributes(const PurpleConvChat *chat, const PurpleConvChatBuddy *cb, const GList *keys_NULL, const GList *values_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbSetAttributes", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, GPOINTER_TO_INT(cb),  	G_TYPE_INT, 0,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conversation_set_logging(const PurpleConversation *conv, gboolean log) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationSetLogging", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_INT, log,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_conversation_is_logging(const PurpleConversation *conv) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationIsLogging", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConvIm* purple_conversation_get_im_data(const PurpleConversation *conv) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetImData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConvIm*) GINT_TO_POINTER(RESULT_ID);
}

PurpleConvChat* purple_conversation_get_chat_data(const PurpleConversation *conv) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetChatData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConvChat*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_get_conversations(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleGetConversations", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_get_ims(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleGetIms", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_get_chats(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleGetChats", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleConversation* purple_find_conversation_with_account(PurpleConversationType type, const char *name, const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleFindConversationWithAccount", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conversation_write(const PurpleConversation *conv, const char *who, const char *message, PurpleMessageFlags flags, time_t mtime) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationWrite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_STRING, who,  	G_TYPE_STRING, message,  	G_TYPE_INT, flags,  	G_TYPE_INT, mtime,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conversation_set_features(const PurpleConversation *conv, PurpleConnectionFlags features) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationSetFeatures", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_INT, features,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConnectionFlags purple_conversation_get_features(const PurpleConversation *conv) {
PurpleConnectionFlags RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetFeatures", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_conversation_has_focus(const PurpleConversation *conv) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationHasFocus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conversation_update(const PurpleConversation *conv, PurpleConvUpdateType type) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationUpdate", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_INT, type,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_conversation_get_message_history(const PurpleConversation *conv) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetMessageHistory", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_conversation_clear_message_history(const PurpleConversation *conv) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationClearMessageHistory", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_conversation_message_get_sender(const PurpleConvMessage *msg) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConversationMessageGetSender", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(msg),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_conversation_message_get_message(const PurpleConvMessage *msg) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConversationMessageGetMessage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(msg),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleMessageFlags purple_conversation_message_get_flags(const PurpleConvMessage *msg) {
PurpleMessageFlags RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationMessageGetFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(msg),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_conversation_message_get_timestamp(const PurpleConvMessage *msg) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConversationMessageGetTimestamp", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(msg),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConversation* purple_conv_im_get_conversation(const PurpleConvIm *im) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvImGetConversation", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conv_im_set_icon(const PurpleConvIm *im, const PurpleBuddyIcon *icon) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImSetIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_INT, GPOINTER_TO_INT(icon),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleBuddyIcon* purple_conv_im_get_icon(const PurpleConvIm *im) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvImGetIcon", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddyIcon*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conv_im_set_typing_state(const PurpleConvIm *im, PurpleTypingState state) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImSetTypingState", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_INT, state,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleTypingState purple_conv_im_get_typing_state(const PurpleConvIm *im) {
PurpleTypingState RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvImGetTypingState", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_im_start_typing_timeout(const PurpleConvIm *im, int timeout) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImStartTypingTimeout", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_INT, timeout,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_im_stop_typing_timeout(const PurpleConvIm *im) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImStopTypingTimeout", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

guint purple_conv_im_get_typing_timeout(const PurpleConvIm *im) {
guint RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvImGetTypingTimeout", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_im_set_type_again(const PurpleConvIm *im, int val) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImSetTypeAgain", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_UINT, val,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

time_t purple_conv_im_get_type_again(const PurpleConvIm *im) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvImGetTypeAgain", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_im_start_send_typed_timeout(const PurpleConvIm *im) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImStartSendTypedTimeout", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_im_stop_send_typed_timeout(const PurpleConvIm *im) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImStopSendTypedTimeout", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

guint purple_conv_im_get_send_typed_timeout(const PurpleConvIm *im) {
guint RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvImGetSendTypedTimeout", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_im_update_typing(const PurpleConvIm *im) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImUpdateTyping", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_im_write(const PurpleConvIm *im, const char *who, const char *message, PurpleMessageFlags flags, time_t mtime) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImWrite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_STRING, who,  	G_TYPE_STRING, message,  	G_TYPE_INT, flags,  	G_TYPE_INT, mtime,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_conv_present_error(const char *who, const PurpleAccount *account, const char *what) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvPresentError", NULL,
	G_TYPE_STRING, who,  	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, what,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_im_send(const PurpleConvIm *im, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImSend", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_send_confirm(const PurpleConversation *conv, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleConvSendConfirm", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_im_send_with_flags(const PurpleConvIm *im, const char *message, PurpleMessageFlags flags) {
dbus_g_proxy_call(purple_proxy, "PurpleConvImSendWithFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(im),  	G_TYPE_STRING, message,  	G_TYPE_INT, flags,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_conv_custom_smiley_add(const PurpleConversation *conv, const char *smile, const char *cksum_type, const char *chksum, gboolean remote) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvCustomSmileyAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_STRING, smile,  	G_TYPE_STRING, cksum_type,  	G_TYPE_STRING, chksum,  	G_TYPE_INT, remote,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_custom_smiley_close(const PurpleConversation *conv, const char *smile) {
dbus_g_proxy_call(purple_proxy, "PurpleConvCustomSmileyClose", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  	G_TYPE_STRING, smile,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConversation* purple_conv_chat_get_conversation(const PurpleConvChat *chat) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetConversation", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_conv_chat_set_users(const PurpleConvChat *chat, const GList *users_NULL) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSetUsers", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_conv_chat_get_users(const PurpleConvChat *chat) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetUsers", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_conv_chat_ignore(const PurpleConvChat *chat, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatIgnore", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_unignore(const PurpleConvChat *chat, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatUnignore", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_conv_chat_set_ignored(const PurpleConvChat *chat, const GList *ignored_NULL) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSetIgnored", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_conv_chat_get_ignored(const PurpleConvChat *chat) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetIgnored", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

char* purple_conv_chat_get_ignored_user(const PurpleConvChat *chat, const char *user) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetIgnoredUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_conv_chat_is_user_ignored(const PurpleConvChat *chat, const char *user) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatIsUserIgnored", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_chat_set_topic(const PurpleConvChat *chat, const char *who, const char *topic) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSetTopic", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, who,  	G_TYPE_STRING, topic,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_conv_chat_get_topic(const PurpleConvChat *chat) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetTopic", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_chat_set_id(const PurpleConvChat *chat, int id) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSetId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

int purple_conv_chat_get_id(const PurpleConvChat *chat) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_chat_write(const PurpleConvChat *chat, const char *who, const char *message, PurpleMessageFlags flags, time_t mtime) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatWrite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, who,  	G_TYPE_STRING, message,  	G_TYPE_INT, flags,  	G_TYPE_INT, mtime,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_send(const PurpleConvChat *chat, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSend", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_send_with_flags(const PurpleConvChat *chat, const char *message, PurpleMessageFlags flags) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSendWithFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, message,  	G_TYPE_INT, flags,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_add_user(const PurpleConvChat *chat, const char *user, const char *extra_msg, PurpleConvChatBuddyFlags flags, gboolean new_arrival) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatAddUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  	G_TYPE_STRING, extra_msg,  	G_TYPE_INT, flags,  	G_TYPE_INT, new_arrival,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_add_users(const PurpleConvChat *chat, const GList *users_NULL, const GList *extra_msgs_NULL, const GList *flags_NULL, gboolean new_arrivals) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatAddUsers", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, 0,  	G_TYPE_INT, 0,  	G_TYPE_INT, 0,  	G_TYPE_INT, new_arrivals,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_rename_user(const PurpleConvChat *chat, const char *old_user, const char *new_user) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatRenameUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, old_user,  	G_TYPE_STRING, new_user,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_remove_user(const PurpleConvChat *chat, const char *user, const char *reason) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatRemoveUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  	G_TYPE_STRING, reason,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_remove_users(const PurpleConvChat *chat, const GList *users_NULL, const char *reason) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatRemoveUsers", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_INT, 0,  	G_TYPE_STRING, reason,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_conv_chat_find_user(const PurpleConvChat *chat, const char *user) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatFindUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_chat_user_set_flags(const PurpleConvChat *chat, const char *user, PurpleConvChatBuddyFlags flags) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatUserSetFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  	G_TYPE_INT, flags,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConvChatBuddyFlags purple_conv_chat_user_get_flags(const PurpleConvChat *chat, const char *user) {
PurpleConvChatBuddyFlags RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatUserGetFlags", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_chat_clear_users(const PurpleConvChat *chat) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatClearUsers", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_set_nick(const PurpleConvChat *chat, const char *nick) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatSetNick", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, nick,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_conv_chat_get_nick(const PurpleConvChat *chat) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatGetNick", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConversation* purple_find_chat(const PurpleConnection *gc, int id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleFindChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

void purple_conv_chat_left(const PurpleConvChat *chat) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatLeft", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conv_chat_invite_user(const PurpleConvChat *chat, const char *user, const char *message, gboolean confirm) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatInviteUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, user,  	G_TYPE_STRING, message,  	G_TYPE_INT, confirm,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_conv_chat_has_left(const PurpleConvChat *chat) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatHasLeft", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleConvChatBuddy* purple_conv_chat_cb_new(const char *name, const char *alias, PurpleConvChatBuddyFlags flags) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbNew", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, alias,  	G_TYPE_INT, flags,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConvChatBuddy*) GINT_TO_POINTER(RESULT_ID);
}

PurpleConvChatBuddy* purple_conv_chat_cb_find(const PurpleConvChat *chat, const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbFind", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(chat),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConvChatBuddy*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_conv_chat_cb_get_name(const PurpleConvChatBuddy *cb) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(cb),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_conv_chat_cb_destroy(const PurpleConvChatBuddy *cb) {
dbus_g_proxy_call(purple_proxy, "PurpleConvChatCbDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(cb),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_conversation_get_extended_menu(const PurpleConversation *conv) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleConversationGetExtendedMenu", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_conversations_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationsInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_conversations_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleConversationsUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_core_init(const char *ui) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleCoreInit", NULL,
	G_TYPE_STRING, ui,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_core_quit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleCoreQuit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_core_get_version(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleCoreGetVersion", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_core_get_ui(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleCoreGetUi", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleCore* purple_get_core(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleGetCore", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleCore*) GINT_TO_POINTER(RESULT_ID);
}

void purple_core_set_ui_ops(const PurpleCoreUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleCoreSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleCoreUiOps* purple_core_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleCoreGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleCoreUiOps*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_core_migrate(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleCoreMigrate", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_core_ensure_single_instance(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleCoreEnsureSingleInstance", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleXfer* purple_xfer_new(const PurpleAccount *account, PurpleXferType type, const char *who) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, type,  	G_TYPE_STRING, who,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleXfer*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_xfers_get_all(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleXfersGetAll", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_xfer_ref(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferRef", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_unref(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferUnref", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_request(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferRequest", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_request_accepted(const PurpleXfer *xfer, const char *filename) {
dbus_g_proxy_call(purple_proxy, "PurpleXferRequestAccepted", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_STRING, filename,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_request_denied(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferRequestDenied", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleXferType purple_xfer_get_type(const PurpleXfer *xfer) {
PurpleXferType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleAccount* purple_xfer_get_account(const PurpleXfer *xfer) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_xfer_get_remote_user(const PurpleXfer *xfer) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetRemoteUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleXferStatusType purple_xfer_get_status(const PurpleXfer *xfer) {
PurpleXferStatusType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_xfer_is_canceled(const PurpleXfer *xfer) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferIsCanceled", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_xfer_is_completed(const PurpleXfer *xfer) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferIsCompleted", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_xfer_get_filename(const PurpleXfer *xfer) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetFilename", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_xfer_get_local_filename(const PurpleXfer *xfer) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetLocalFilename", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

size_t purple_xfer_get_bytes_sent(const PurpleXfer *xfer) {
size_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetBytesSent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

size_t purple_xfer_get_bytes_remaining(const PurpleXfer *xfer) {
size_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetBytesRemaining", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

size_t purple_xfer_get_size(const PurpleXfer *xfer) {
size_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetSize", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_xfer_get_local_port(const PurpleXfer *xfer) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetLocalPort", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_UINT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_xfer_get_remote_ip(const PurpleXfer *xfer) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetRemoteIp", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_xfer_get_remote_port(const PurpleXfer *xfer) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetRemotePort", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_UINT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_xfer_get_start_time(const PurpleXfer *xfer) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetStartTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_xfer_get_end_time(const PurpleXfer *xfer) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetEndTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_xfer_set_completed(const PurpleXfer *xfer, gboolean completed) {
dbus_g_proxy_call(purple_proxy, "PurpleXferSetCompleted", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_INT, completed,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_set_message(const PurpleXfer *xfer, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleXferSetMessage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_set_filename(const PurpleXfer *xfer, const char *filename) {
dbus_g_proxy_call(purple_proxy, "PurpleXferSetFilename", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_STRING, filename,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_set_local_filename(const PurpleXfer *xfer, const char *filename) {
dbus_g_proxy_call(purple_proxy, "PurpleXferSetLocalFilename", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_STRING, filename,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_set_size(const PurpleXfer *xfer, size_t size) {
dbus_g_proxy_call(purple_proxy, "PurpleXferSetSize", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_INT, size,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_set_bytes_sent(const PurpleXfer *xfer, size_t bytes_sent) {
dbus_g_proxy_call(purple_proxy, "PurpleXferSetBytesSent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_INT, bytes_sent,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleXferUiOps* purple_xfer_get_ui_ops(const PurpleXfer *xfer) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleXferUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_xfer_start(const PurpleXfer *xfer, int fd, const char *ip, int port) {
dbus_g_proxy_call(purple_proxy, "PurpleXferStart", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_INT, fd,  	G_TYPE_STRING, ip,  	G_TYPE_UINT, port,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_end(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferEnd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_add(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_cancel_local(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferCancelLocal", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_cancel_remote(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferCancelRemote", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_error(PurpleXferType type, const PurpleAccount *account, const char *who, const char *msg) {
dbus_g_proxy_call(purple_proxy, "PurpleXferError", NULL,
	G_TYPE_INT, type,  	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, who,  	G_TYPE_STRING, msg,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfer_update_progress(const PurpleXfer *xfer) {
dbus_g_proxy_call(purple_proxy, "PurpleXferUpdateProgress", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_xfer_get_thumbnail_mimetype(const PurpleXfer *xfer) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleXferGetThumbnailMimetype", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_xfer_prepare_thumbnail(const PurpleXfer *xfer, const char *formats) {
dbus_g_proxy_call(purple_proxy, "PurpleXferPrepareThumbnail", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(xfer),  	G_TYPE_STRING, formats,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfers_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleXfersInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfers_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleXfersUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_xfers_set_ui_ops(const PurpleXferUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleXfersSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleXferUiOps* purple_xfers_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleXfersGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleXferUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_log_free(const PurpleLog *log) {
dbus_g_proxy_call(purple_proxy, "PurpleLogFree", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_log_write(const PurpleLog *log, PurpleMessageFlags type, const char *from, time_t time, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleLogWrite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  	G_TYPE_INT, type,  	G_TYPE_STRING, from,  	G_TYPE_INT, time,  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_log_get_logs(PurpleLogType type, const char *name, const PurpleAccount *account) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleLogGetLogs", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_log_get_system_logs(const PurpleAccount *account) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleLogGetSystemLogs", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

int purple_log_get_size(const PurpleLog *log) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogGetSize", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_log_get_total_size(PurpleLogType type, const char *name, const PurpleAccount *account) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogGetTotalSize", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_log_get_activity_score(PurpleLogType type, const char *name, const PurpleAccount *account) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogGetActivityScore", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_log_is_deletable(const PurpleLog *log) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogIsDeletable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_log_delete(const PurpleLog *log) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogDelete", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_log_get_log_dir(PurpleLogType type, const char *name, const PurpleAccount *account) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleLogGetLogDir", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_log_set_free(const PurpleLogSet *set) {
dbus_g_proxy_call(purple_proxy, "PurpleLogSetFree", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(set),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_log_common_writer(const PurpleLog *log, const char *ext) {
dbus_g_proxy_call(purple_proxy, "PurpleLogCommonWriter", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  	G_TYPE_STRING, ext,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_log_common_lister(PurpleLogType type, const char *name, const PurpleAccount *account, const char *ext, const PurpleLogLogger *logger) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleLogCommonLister", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ext,  	G_TYPE_INT, GPOINTER_TO_INT(logger),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

int purple_log_common_total_sizer(PurpleLogType type, const char *name, const PurpleAccount *account, const char *ext) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogCommonTotalSizer", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, ext,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_log_common_sizer(const PurpleLog *log) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogCommonSizer", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_log_common_deleter(const PurpleLog *log) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogCommonDeleter", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_log_common_is_deletable(const PurpleLog *log) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogCommonIsDeletable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(log),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_log_logger_free(const PurpleLogLogger *logger) {
dbus_g_proxy_call(purple_proxy, "PurpleLogLoggerFree", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(logger),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_log_logger_add(const PurpleLogLogger *logger) {
dbus_g_proxy_call(purple_proxy, "PurpleLogLoggerAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(logger),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_log_logger_remove(const PurpleLogLogger *logger) {
dbus_g_proxy_call(purple_proxy, "PurpleLogLoggerRemove", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(logger),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_log_logger_set(const PurpleLogLogger *logger) {
dbus_g_proxy_call(purple_proxy, "PurpleLogLoggerSet", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(logger),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleLogLogger* purple_log_logger_get(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleLogLoggerGet", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleLogLogger*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_log_logger_get_options(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleLogLoggerGetOptions", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_log_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleLogInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_log_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleLogUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_searchresults_free(const PurpleNotifySearchResults *results) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsFree", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_searchresults_new_rows(const PurpleConnection *gc, const PurpleNotifySearchResults *results, const void *data_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsNewRows", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, GPOINTER_TO_INT(results),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleNotifySearchResults* purple_notify_searchresults_new(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsNew", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleNotifySearchResults*) GINT_TO_POINTER(RESULT_ID);
}

PurpleNotifySearchColumn* purple_notify_searchresults_column_new(const char *title) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsColumnNew", NULL,
	G_TYPE_STRING, title,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleNotifySearchColumn*) GINT_TO_POINTER(RESULT_ID);
}

void purple_notify_searchresults_column_add(const PurpleNotifySearchResults *results, const PurpleNotifySearchColumn *column) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsColumnAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  	G_TYPE_INT, GPOINTER_TO_INT(column),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_searchresults_row_add(const PurpleNotifySearchResults *results, const GList *row_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsRowAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

guint purple_notify_searchresults_get_rows_count(const PurpleNotifySearchResults *results) {
guint RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsGetRowsCount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

guint purple_notify_searchresults_get_columns_count(const PurpleNotifySearchResults *results) {
guint RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsGetColumnsCount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_notify_searchresults_row_get(const PurpleNotifySearchResults *results, int row_id) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsRowGet", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  	G_TYPE_UINT, row_id,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

char* purple_notify_searchresults_column_get_title(const PurpleNotifySearchResults *results, int column_id) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleNotifySearchresultsColumnGetTitle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(results),  	G_TYPE_UINT, column_id,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleNotifyUserInfo* purple_notify_user_info_new(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoNew", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleNotifyUserInfo*) GINT_TO_POINTER(RESULT_ID);
}

void purple_notify_user_info_destroy(const PurpleNotifyUserInfo *user_info) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_notify_user_info_get_entries(const PurpleNotifyUserInfo *user_info) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoGetEntries", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

char* purple_notify_user_info_get_text_with_newline(const PurpleNotifyUserInfo *user_info, const char *newline) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoGetTextWithNewline", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_STRING, newline,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_notify_user_info_add_pair(const PurpleNotifyUserInfo *user_info, const char *label, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoAddPair", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_STRING, label,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_add_pair_plaintext(const PurpleNotifyUserInfo *user_info, const char *label, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoAddPairPlaintext", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_STRING, label,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_prepend_pair(const PurpleNotifyUserInfo *user_info, const char *label, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoPrependPair", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_STRING, label,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_remove_entry(const PurpleNotifyUserInfo *user_info, const PurpleNotifyUserInfoEntry *user_info_entry) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoRemoveEntry", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleNotifyUserInfoEntry* purple_notify_user_info_entry_new(const char *label, const char *value) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntryNew", NULL,
	G_TYPE_STRING, label,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleNotifyUserInfoEntry*) GINT_TO_POINTER(RESULT_ID);
}

void purple_notify_user_info_add_section_break(const PurpleNotifyUserInfo *user_info) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoAddSectionBreak", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_prepend_section_break(const PurpleNotifyUserInfo *user_info) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoPrependSectionBreak", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_add_section_header(const PurpleNotifyUserInfo *user_info, const char *label) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoAddSectionHeader", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_STRING, label,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_prepend_section_header(const PurpleNotifyUserInfo *user_info, const char *label) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoPrependSectionHeader", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  	G_TYPE_STRING, label,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_user_info_remove_last_item(const PurpleNotifyUserInfo *user_info) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoRemoveLastItem", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_notify_user_info_entry_get_label(const PurpleNotifyUserInfoEntry *user_info_entry) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntryGetLabel", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_notify_user_info_entry_set_label(const PurpleNotifyUserInfoEntry *user_info_entry, const char *label) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntrySetLabel", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  	G_TYPE_STRING, label,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_notify_user_info_entry_get_value(const PurpleNotifyUserInfoEntry *user_info_entry) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntryGetValue", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_notify_user_info_entry_set_value(const PurpleNotifyUserInfoEntry *user_info_entry, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntrySetValue", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleNotifyUserInfoEntryType purple_notify_user_info_entry_get_type(const PurpleNotifyUserInfoEntry *user_info_entry) {
PurpleNotifyUserInfoEntryType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntryGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_notify_user_info_entry_set_type(const PurpleNotifyUserInfoEntry *user_info_entry, PurpleNotifyUserInfoEntryType type) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUserInfoEntrySetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(user_info_entry),  	G_TYPE_INT, type,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_close(PurpleNotifyType type, const void *ui_handle_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyClose", NULL,
	G_TYPE_INT, type,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_close_with_handle(const void *handle_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyCloseWithHandle", NULL,
	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_set_ui_ops(const PurpleNotifyUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifySetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleNotifyUiOps* purple_notify_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleNotifyGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleNotifyUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_notify_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_notify_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleNotifyUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_ui_ops(const PurplePrefsUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurplePrefsUiOps* purple_prefs_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePrefsUiOps*) GINT_TO_POINTER(RESULT_ID);
}

void purple_prefs_init(void) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_none(const char *name) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddNone", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_bool(const char *name, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddBool", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_int(const char *name, int value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddInt", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_string(const char *name, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddString", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_string_list(const char *name, const GList *value_NULL) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddStringList", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_path(const char *name, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddPath", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_add_path_list(const char *name, const GList *value_NULL) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsAddPathList", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_remove(const char *name) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsRemove", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_rename(const char *oldname, const char *newname) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsRename", NULL,
	G_TYPE_STRING, oldname,  	G_TYPE_STRING, newname,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_rename_boolean_toggle(const char *oldname, const char *newname) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsRenameBooleanToggle", NULL,
	G_TYPE_STRING, oldname,  	G_TYPE_STRING, newname,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_destroy(void) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsDestroy", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_bool(const char *name, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetBool", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_int(const char *name, int value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetInt", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_string(const char *name, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetString", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_string_list(const char *name, const GList *value_NULL) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetStringList", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_path(const char *name, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetPath", NULL,
	G_TYPE_STRING, name,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_set_path_list(const char *name, const GList *value_NULL) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsSetPathList", NULL,
	G_TYPE_STRING, name,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_prefs_exists(const char *name) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrefsExists", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurplePrefType purple_prefs_get_type(const char *name) {
PurplePrefType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetType", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_prefs_get_bool(const char *name) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetBool", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_prefs_get_int(const char *name) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetInt", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_prefs_get_string(const char *name) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetString", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_prefs_get_string_list(const char *name) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetStringList", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

char* purple_prefs_get_path(const char *name) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetPath", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_prefs_get_path_list(const char *name) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetPathList", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_prefs_get_children_names(const char *name) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurplePrefsGetChildrenNames", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_prefs_disconnect_callback(guint callback_id) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsDisconnectCallback", NULL,
	G_TYPE_INT, callback_id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_disconnect_by_handle(const void *handle_NULL) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsDisconnectByHandle", NULL,
	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_trigger_callback(const char *name) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsTriggerCallback", NULL,
	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prefs_trigger_callback_object(const PurplePrefCallbackData *data) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsTriggerCallbackObject", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(data),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_prefs_load(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrefsLoad", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_prefs_update_old(void) {
dbus_g_proxy_call(purple_proxy, "PurplePrefsUpdateOld", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_roomlist_show_with_account(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistShowWithAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleRoomlist* purple_roomlist_new(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleRoomlist*) GINT_TO_POINTER(RESULT_ID);
}

void purple_roomlist_ref(const PurpleRoomlist *list) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRef", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_roomlist_unref(const PurpleRoomlist *list) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistUnref", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_roomlist_set_fields(const PurpleRoomlist *list, const GList *fields_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistSetFields", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_roomlist_set_in_progress(const PurpleRoomlist *list, gboolean in_progress) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistSetInProgress", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  	G_TYPE_INT, in_progress,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_roomlist_get_in_progress(const PurpleRoomlist *list) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistGetInProgress", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_roomlist_room_add(const PurpleRoomlist *list, const PurpleRoomlistRoom *room) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomAdd", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  	G_TYPE_INT, GPOINTER_TO_INT(room),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleRoomlist* purple_roomlist_get_list(const PurpleConnection *gc) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistGetList", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleRoomlist*) GINT_TO_POINTER(RESULT_ID);
}

void purple_roomlist_cancel_get_list(const PurpleRoomlist *list) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistCancelGetList", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_roomlist_expand_category(const PurpleRoomlist *list, const PurpleRoomlistRoom *category) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistExpandCategory", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  	G_TYPE_INT, GPOINTER_TO_INT(category),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_roomlist_get_fields(const PurpleRoomlist *roomlist) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistGetFields", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(roomlist),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleRoomlistRoom* purple_roomlist_room_new(PurpleRoomlistRoomType type, const char *name, const PurpleRoomlistRoom *parent) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomNew", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(parent),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleRoomlistRoom*) GINT_TO_POINTER(RESULT_ID);
}

void purple_roomlist_room_join(const PurpleRoomlist *list, const PurpleRoomlistRoom *room) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomJoin", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(list),  	G_TYPE_INT, GPOINTER_TO_INT(room),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleRoomlistRoomType purple_roomlist_room_get_type(const PurpleRoomlistRoom *room) {
PurpleRoomlistRoomType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(room),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_roomlist_room_get_name(const PurpleRoomlistRoom *room) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(room),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleRoomlistRoom* purple_roomlist_room_get_parent(const PurpleRoomlistRoom *room) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomGetParent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(room),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleRoomlistRoom*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_roomlist_room_get_fields(const PurpleRoomlistRoom *room) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistRoomGetFields", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(room),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleRoomlistField* purple_roomlist_field_new(PurpleRoomlistFieldType type, const char *label, const char *name, gboolean hidden) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistFieldNew", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, label,  	G_TYPE_STRING, name,  	G_TYPE_INT, hidden,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleRoomlistField*) GINT_TO_POINTER(RESULT_ID);
}

PurpleRoomlistFieldType purple_roomlist_field_get_type(const PurpleRoomlistField *field) {
PurpleRoomlistFieldType RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistFieldGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(field),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_roomlist_field_get_label(const PurpleRoomlistField *field) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistFieldGetLabel", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(field),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_roomlist_field_get_hidden(const PurpleRoomlistField *field) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistFieldGetHidden", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(field),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_roomlist_set_ui_ops(const PurpleRoomlistUiOps *ops) {
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistSetUiOps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(ops),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleRoomlistUiOps* purple_roomlist_get_ui_ops(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRoomlistGetUiOps", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleRoomlistUiOps*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSavedStatus* purple_savedstatus_new(const char *title, PurpleStatusPrimitive type) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusNew", NULL,
	G_TYPE_STRING, title,  	G_TYPE_INT, type,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

void purple_savedstatus_set_title(const PurpleSavedStatus *status, const char *title) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSetTitle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, title,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatus_set_type(const PurpleSavedStatus *status, PurpleStatusPrimitive type) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_INT, type,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatus_set_message(const PurpleSavedStatus *status, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSetMessage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatus_set_substatus(const PurpleSavedStatus *status, const PurpleAccount *account, const PurpleStatusType *type, const char *message) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSetSubstatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(type),  	G_TYPE_STRING, message,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatus_unset_substatus(const PurpleSavedStatus *saved_status, const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusUnsetSubstatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_savedstatus_delete(const char *title) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusDelete", NULL,
	G_TYPE_STRING, title,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_savedstatus_delete_by_status(const PurpleSavedStatus *saved_status) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusDeleteByStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_savedstatuses_get_all(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusesGetAll", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_savedstatuses_get_popular(int how_many) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusesGetPopular", NULL,
	G_TYPE_UINT, how_many,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleSavedStatus* purple_savedstatus_get_current(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetCurrent", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSavedStatus* purple_savedstatus_get_default(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetDefault", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSavedStatus* purple_savedstatus_get_idleaway(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetIdleaway", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_savedstatus_is_idleaway(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusIsIdleaway", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_savedstatus_set_idleaway(gboolean idleaway) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSetIdleaway", NULL,
	G_TYPE_INT, idleaway,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleSavedStatus* purple_savedstatus_get_startup(void) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetStartup", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSavedStatus* purple_savedstatus_find(const char *title) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusFind", NULL,
	G_TYPE_STRING, title,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSavedStatus* purple_savedstatus_find_by_creation_time(time_t creation_time) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusFindByCreationTime", NULL,
	G_TYPE_INT, creation_time,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSavedStatus* purple_savedstatus_find_transient_by_type_and_message(PurpleStatusPrimitive type, const char *message) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusFindTransientByTypeAndMessage", NULL,
	G_TYPE_INT, type,  	G_TYPE_STRING, message,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatus*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_savedstatus_is_transient(const PurpleSavedStatus *saved_status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusIsTransient", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_savedstatus_get_title(const PurpleSavedStatus *saved_status) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetTitle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStatusPrimitive purple_savedstatus_get_type(const PurpleSavedStatus *saved_status) {
PurpleStatusPrimitive RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_savedstatus_get_message(const PurpleSavedStatus *saved_status) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetMessage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_savedstatus_get_creation_time(const PurpleSavedStatus *saved_status) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetCreationTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_savedstatus_has_substatuses(const PurpleSavedStatus *saved_status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusHasSubstatuses", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleSavedStatusSub* purple_savedstatus_get_substatus(const PurpleSavedStatus *saved_status, const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusGetSubstatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSavedStatusSub*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatusType* purple_savedstatus_substatus_get_type(const PurpleSavedStatusSub *substatus) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSubstatusGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(substatus),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_savedstatus_substatus_get_message(const PurpleSavedStatusSub *substatus) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusSubstatusGetMessage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(substatus),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_savedstatus_activate(const PurpleSavedStatus *saved_status) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusActivate", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatus_activate_for_account(const PurpleSavedStatus *saved_status, const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusActivateForAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(saved_status),  	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatuses_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusesInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_savedstatuses_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleSavedstatusesUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleSmiley* purple_smiley_new(const PurpleStoredImage *img, const char *shortcut) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(img),  	G_TYPE_STRING, shortcut,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSmiley*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSmiley* purple_smiley_new_from_file(const char *shortcut, const char *filepath) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyNewFromFile", NULL,
	G_TYPE_STRING, shortcut,  	G_TYPE_STRING, filepath,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSmiley*) GINT_TO_POINTER(RESULT_ID);
}

void purple_smiley_delete(const PurpleSmiley *smiley) {
dbus_g_proxy_call(purple_proxy, "PurpleSmileyDelete", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

gboolean purple_smiley_set_shortcut(const PurpleSmiley *smiley, const char *shortcut) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSmileySetShortcut", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  	G_TYPE_STRING, shortcut,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_smiley_set_data(const PurpleSmiley *smiley, const guchar *smiley_data_NULL, size_t smiley_data_len) {
dbus_g_proxy_call(purple_proxy, "PurpleSmileySetData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  	G_TYPE_INT, 0,  	G_TYPE_INT, smiley_data_len,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_smiley_get_shortcut(const PurpleSmiley *smiley) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyGetShortcut", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_smiley_get_checksum(const PurpleSmiley *smiley) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyGetChecksum", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStoredImage* purple_smiley_get_stored_image(const PurpleSmiley *smiley) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyGetStoredImage", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStoredImage*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_smiley_get_extension(const PurpleSmiley *smiley) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyGetExtension", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_smiley_get_full_path(const PurpleSmiley *smiley) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSmileyGetFullPath", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(smiley),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_smileys_get_all(void) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleSmileysGetAll", NULL,
G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleSmiley* purple_smileys_find_by_shortcut(const char *shortcut) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSmileysFindByShortcut", NULL,
	G_TYPE_STRING, shortcut,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSmiley*) GINT_TO_POINTER(RESULT_ID);
}

PurpleSmiley* purple_smileys_find_by_checksum(const char *checksum) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSmileysFindByChecksum", NULL,
	G_TYPE_STRING, checksum,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleSmiley*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_smileys_get_storing_dir(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleSmileysGetStoringDir", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_smileys_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleSmileysInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_smileys_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleSmileysUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_primitive_get_id_from_type(PurpleStatusPrimitive type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurplePrimitiveGetIdFromType", NULL,
	G_TYPE_INT, type,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_primitive_get_name_from_type(PurpleStatusPrimitive type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurplePrimitiveGetNameFromType", NULL,
	G_TYPE_INT, type,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStatusPrimitive purple_primitive_get_type_from_id(const char *id) {
PurpleStatusPrimitive RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrimitiveGetTypeFromId", NULL,
	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStatusType* purple_status_type_new_full(PurpleStatusPrimitive primitive, const char *id, const char *name, gboolean saveable, gboolean user_settable, gboolean independent) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeNewFull", NULL,
	G_TYPE_INT, primitive,  	G_TYPE_STRING, id,  	G_TYPE_STRING, name,  	G_TYPE_INT, saveable,  	G_TYPE_INT, user_settable,  	G_TYPE_INT, independent,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatusType* purple_status_type_new(PurpleStatusPrimitive primitive, const char *id, const char *name, gboolean user_settable) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeNew", NULL,
	G_TYPE_INT, primitive,  	G_TYPE_STRING, id,  	G_TYPE_STRING, name,  	G_TYPE_INT, user_settable,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

void purple_status_type_destroy(const PurpleStatusType *status_type) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_type_set_primary_attr(const PurpleStatusType *status_type, const char *attr_id) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeSetPrimaryAttr", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  	G_TYPE_STRING, attr_id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_type_add_attr(const PurpleStatusType *status_type, const char *id, const char *name, const PurpleValue *value) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeAddAttr", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  	G_TYPE_STRING, id,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(value),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleStatusPrimitive purple_status_type_get_primitive(const PurpleStatusType *status_type) {
PurpleStatusPrimitive RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeGetPrimitive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_status_type_get_id(const PurpleStatusType *status_type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeGetId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_status_type_get_name(const PurpleStatusType *status_type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_type_is_saveable(const PurpleStatusType *status_type) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeIsSaveable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_type_is_user_settable(const PurpleStatusType *status_type) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeIsUserSettable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_type_is_independent(const PurpleStatusType *status_type) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeIsIndependent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_type_is_exclusive(const PurpleStatusType *status_type) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeIsExclusive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_type_is_available(const PurpleStatusType *status_type) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeIsAvailable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_status_type_get_primary_attr(const PurpleStatusType *type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeGetPrimaryAttr", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleStatusAttr* purple_status_type_get_attr(const PurpleStatusType *status_type, const char *id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeGetAttr", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusAttr*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_status_type_get_attrs(const PurpleStatusType *status_type) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeGetAttrs", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleStatusType* purple_status_type_find_with_id(const GList *status_types_NULL, const char *id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusTypeFindWithId", NULL,
	G_TYPE_INT, 0,  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatusAttr* purple_status_attr_new(const char *id, const char *name, const PurpleValue *value_type) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusAttrNew", NULL,
	G_TYPE_STRING, id,  	G_TYPE_STRING, name,  	G_TYPE_INT, GPOINTER_TO_INT(value_type),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusAttr*) GINT_TO_POINTER(RESULT_ID);
}

void purple_status_attr_destroy(const PurpleStatusAttr *attr) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusAttrDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(attr),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_status_attr_get_id(const PurpleStatusAttr *attr) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusAttrGetId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(attr),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_status_attr_get_name(const PurpleStatusAttr *attr) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusAttrGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(attr),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleValue* purple_status_attr_get_value(const PurpleStatusAttr *attr) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusAttrGetValue", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(attr),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleValue*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatus* purple_status_new(const PurpleStatusType *status_type, const PurplePresence *presence) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusNew", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status_type),  	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatus*) GINT_TO_POINTER(RESULT_ID);
}

void purple_status_destroy(const PurpleStatus *status) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_set_active(const PurpleStatus *status, gboolean active) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusSetActive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_INT, active,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_set_active_with_attrs_list(const PurpleStatus *status, gboolean active, const GList *attrs_NULL) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusSetActiveWithAttrsList", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_INT, active,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_set_attr_boolean(const PurpleStatus *status, const char *id, gboolean value) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusSetAttrBoolean", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_set_attr_int(const PurpleStatus *status, const char *id, int value) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusSetAttrInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  	G_TYPE_INT, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_set_attr_string(const PurpleStatus *status, const char *id, const char *value) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusSetAttrString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleStatusType* purple_status_get_type(const PurpleStatus *status) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetType", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatusType*) GINT_TO_POINTER(RESULT_ID);
}

PurplePresence* purple_status_get_presence(const PurpleStatus *status) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetPresence", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_status_get_id(const PurpleStatus *status) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetId", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_status_get_name(const PurpleStatus *status) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_is_independent(const PurpleStatus *status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusIsIndependent", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_is_exclusive(const PurpleStatus *status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusIsExclusive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_is_available(const PurpleStatus *status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusIsAvailable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_is_active(const PurpleStatus *status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusIsActive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_status_is_online(const PurpleStatus *status) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusIsOnline", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleValue* purple_status_get_attr_value(const PurpleStatus *status, const char *id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetAttrValue", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleValue*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_status_get_attr_boolean(const PurpleStatus *status, const char *id) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetAttrBoolean", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_status_get_attr_int(const PurpleStatus *status, const char *id) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetAttrInt", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_status_get_attr_string(const PurpleStatus *status, const char *id) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStatusGetAttrString", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status),  	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gint purple_status_compare(const PurpleStatus *status1, const PurpleStatus *status2) {
gint RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStatusCompare", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(status1),  	G_TYPE_INT, GPOINTER_TO_INT(status2),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurplePresence* purple_presence_new(PurplePresenceContext context) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceNew", NULL,
	G_TYPE_INT, context,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

PurplePresence* purple_presence_new_for_account(const PurpleAccount *account) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceNewForAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

PurplePresence* purple_presence_new_for_conv(const PurpleConversation *conv) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceNewForConv", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(conv),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

PurplePresence* purple_presence_new_for_buddy(const PurpleBuddy *buddy) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceNewForBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(buddy),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePresence*) GINT_TO_POINTER(RESULT_ID);
}

void purple_presence_destroy(const PurplePresence *presence) {
dbus_g_proxy_call(purple_proxy, "PurplePresenceDestroy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_presence_add_status(const PurplePresence *presence, const PurpleStatus *status) {
dbus_g_proxy_call(purple_proxy, "PurplePresenceAddStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_INT, GPOINTER_TO_INT(status),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_presence_set_status_active(const PurplePresence *presence, const char *status_id, gboolean active) {
dbus_g_proxy_call(purple_proxy, "PurplePresenceSetStatusActive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_STRING, status_id,  	G_TYPE_INT, active,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_presence_switch_status(const PurplePresence *presence, const char *status_id) {
dbus_g_proxy_call(purple_proxy, "PurplePresenceSwitchStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_STRING, status_id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_presence_set_idle(const PurplePresence *presence, gboolean idle, time_t idle_time) {
dbus_g_proxy_call(purple_proxy, "PurplePresenceSetIdle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_INT, idle,  	G_TYPE_INT, idle_time,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_presence_set_login_time(const PurplePresence *presence, time_t login_time) {
dbus_g_proxy_call(purple_proxy, "PurplePresenceSetLoginTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_INT, login_time,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurplePresenceContext purple_presence_get_context(const PurplePresence *presence) {
PurplePresenceContext RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetContext", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleAccount* purple_presence_get_account(const PurplePresence *presence) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetAccount", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAccount*) GINT_TO_POINTER(RESULT_ID);
}

PurpleConversation* purple_presence_get_conversation(const PurplePresence *presence) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetConversation", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

char* purple_presence_get_chat_user(const PurplePresence *presence) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetChatUser", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleBuddy* purple_presence_get_buddy(const PurplePresence *presence) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleBuddy*) GINT_TO_POINTER(RESULT_ID);
}

GList* purple_presence_get_statuses(const PurplePresence *presence) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetStatuses", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

PurpleStatus* purple_presence_get_status(const PurplePresence *presence, const char *status_id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_STRING, status_id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatus*) GINT_TO_POINTER(RESULT_ID);
}

PurpleStatus* purple_presence_get_active_status(const PurplePresence *presence) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetActiveStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleStatus*) GINT_TO_POINTER(RESULT_ID);
}

gboolean purple_presence_is_available(const PurplePresence *presence) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceIsAvailable", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_presence_is_online(const PurplePresence *presence) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceIsOnline", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_presence_is_status_active(const PurplePresence *presence, const char *status_id) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceIsStatusActive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_STRING, status_id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_presence_is_status_primitive_active(const PurplePresence *presence, PurpleStatusPrimitive primitive) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceIsStatusPrimitiveActive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  	G_TYPE_INT, primitive,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_presence_is_idle(const PurplePresence *presence) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceIsIdle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_presence_get_idle_time(const PurplePresence *presence) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetIdleTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_presence_get_login_time(const PurplePresence *presence) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceGetLoginTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gint purple_presence_compare(const PurplePresence *presence1, const PurplePresence *presence2) {
gint RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePresenceCompare", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(presence1),  	G_TYPE_INT, GPOINTER_TO_INT(presence2),  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_status_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_status_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleStatusUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

int serv_send_typing(const PurpleConnection *gc, const char *name, PurpleTypingState state) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "ServSendTyping", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, name,  	G_TYPE_INT, state,  G_TYPE_INVALID,
	G_TYPE_UINT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void serv_move_buddy(const PurpleBuddy *param0, const PurpleGroup *param1, const PurpleGroup *param2) {
dbus_g_proxy_call(purple_proxy, "ServMoveBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_INT, GPOINTER_TO_INT(param1),  	G_TYPE_INT, GPOINTER_TO_INT(param2),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

int serv_send_im(const PurpleConnection *param0, const char *param1, const char *param2, PurpleMessageFlags flags) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "ServSendIm", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  	G_TYPE_STRING, param2,  	G_TYPE_INT, flags,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

PurpleAttentionType* purple_get_attention_type_from_code(const PurpleAccount *account, guint type_code) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleGetAttentionTypeFromCode", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, type_code,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAttentionType*) GINT_TO_POINTER(RESULT_ID);
}

void serv_send_attention(const PurpleConnection *gc, const char *who, guint type_code) {
dbus_g_proxy_call(purple_proxy, "ServSendAttention", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_INT, type_code,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_attention(const PurpleConnection *gc, const char *who, guint type_code) {
dbus_g_proxy_call(purple_proxy, "ServGotAttention", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_INT, type_code,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_get_info(const PurpleConnection *param0, const char *param1) {
dbus_g_proxy_call(purple_proxy, "ServGetInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_set_info(const PurpleConnection *param0, const char *param1) {
dbus_g_proxy_call(purple_proxy, "ServSetInfo", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_add_permit(const PurpleConnection *param0, const char *param1) {
dbus_g_proxy_call(purple_proxy, "ServAddPermit", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_add_deny(const PurpleConnection *param0, const char *param1) {
dbus_g_proxy_call(purple_proxy, "ServAddDeny", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_rem_permit(const PurpleConnection *param0, const char *param1) {
dbus_g_proxy_call(purple_proxy, "ServRemPermit", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_rem_deny(const PurpleConnection *param0, const char *param1) {
dbus_g_proxy_call(purple_proxy, "ServRemDeny", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_STRING, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_set_permit_deny(const PurpleConnection *param0) {
dbus_g_proxy_call(purple_proxy, "ServSetPermitDeny", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_chat_invite(const PurpleConnection *param0, int param1, const char *param2, const char *param3) {
dbus_g_proxy_call(purple_proxy, "ServChatInvite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_INT, param1,  	G_TYPE_STRING, param2,  	G_TYPE_STRING, param3,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_chat_leave(const PurpleConnection *param0, int param1) {
dbus_g_proxy_call(purple_proxy, "ServChatLeave", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_INT, param1,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_chat_whisper(const PurpleConnection *param0, int param1, const char *param2, const char *param3) {
dbus_g_proxy_call(purple_proxy, "ServChatWhisper", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_INT, param1,  	G_TYPE_STRING, param2,  	G_TYPE_STRING, param3,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

int serv_chat_send(const PurpleConnection *param0, int param1, const char *param2, PurpleMessageFlags flags) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "ServChatSend", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	G_TYPE_INT, param1,  	G_TYPE_STRING, param2,  	G_TYPE_INT, flags,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void serv_alias_buddy(const PurpleBuddy *param0) {
dbus_g_proxy_call(purple_proxy, "ServAliasBuddy", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_alias(const PurpleConnection *gc, const char *who, const char *alias) {
dbus_g_proxy_call(purple_proxy, "ServGotAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_serv_got_private_alias(const PurpleConnection *gc, const char *who, const char *alias) {
dbus_g_proxy_call(purple_proxy, "PurpleServGotPrivateAlias", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_STRING, alias,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_typing(const PurpleConnection *gc, const char *name, int timeout, PurpleTypingState state) {
dbus_g_proxy_call(purple_proxy, "ServGotTyping", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, name,  	G_TYPE_INT, timeout,  	G_TYPE_INT, state,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_typing_stopped(const PurpleConnection *gc, const char *name) {
dbus_g_proxy_call(purple_proxy, "ServGotTypingStopped", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_im(const PurpleConnection *gc, const char *who, const char *msg, PurpleMessageFlags flags, time_t mtime) {
dbus_g_proxy_call(purple_proxy, "ServGotIm", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_STRING, msg,  	G_TYPE_INT, flags,  	G_TYPE_INT, mtime,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_join_chat(const PurpleConnection *param0, const GHashTable *data) {
dbus_g_proxy_call(purple_proxy, "ServJoinChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), data,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_reject_chat(const PurpleConnection *param0, const GHashTable *data) {
dbus_g_proxy_call(purple_proxy, "ServRejectChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(param0),  	dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), data,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_chat_invite(const PurpleConnection *gc, const char *name, const char *who, const char *message, const GHashTable *data) {
dbus_g_proxy_call(purple_proxy, "ServGotChatInvite", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, name,  	G_TYPE_STRING, who,  	G_TYPE_STRING, message,  	dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), data,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleConversation* serv_got_joined_chat(const PurpleConnection *gc, int id, const char *name) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "ServGotJoinedChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, id,  	G_TYPE_STRING, name,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleConversation*) GINT_TO_POINTER(RESULT_ID);
}

void purple_serv_got_join_chat_failed(const PurpleConnection *gc, const GHashTable *data) {
dbus_g_proxy_call(purple_proxy, "PurpleServGotJoinChatFailed", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	dbus_g_type_get_map ("GHashTable", G_TYPE_STRING, G_TYPE_STRING), data,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_chat_left(const PurpleConnection *g, int id) {
dbus_g_proxy_call(purple_proxy, "ServGotChatLeft", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(g),  	G_TYPE_INT, id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_got_chat_in(const PurpleConnection *g, int id, const char *who, PurpleMessageFlags flags, const char *message, time_t mtime) {
dbus_g_proxy_call(purple_proxy, "ServGotChatIn", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(g),  	G_TYPE_INT, id,  	G_TYPE_STRING, who,  	G_TYPE_INT, flags,  	G_TYPE_STRING, message,  	G_TYPE_INT, mtime,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_send_file(const PurpleConnection *gc, const char *who, const char *file) {
dbus_g_proxy_call(purple_proxy, "ServSendFile", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_STRING, file,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void serv_chat_send_file(const PurpleConnection *gc, int id, const char *file) {
dbus_g_proxy_call(purple_proxy, "ServChatSendFile", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, id,  	G_TYPE_STRING, file,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_menu_action_free(const PurpleMenuAction *act) {
dbus_g_proxy_call(purple_proxy, "PurpleMenuActionFree", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(act),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_util_set_current_song(const char *title, const char *artist, const char *album) {
dbus_g_proxy_call(purple_proxy, "PurpleUtilSetCurrentSong", NULL,
	G_TYPE_STRING, title,  	G_TYPE_STRING, artist,  	G_TYPE_STRING, album,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_util_init(void) {
dbus_g_proxy_call(purple_proxy, "PurpleUtilInit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_util_uninit(void) {
dbus_g_proxy_call(purple_proxy, "PurpleUtilUninit", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_mime_decode_field(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMimeDecodeField", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

time_t purple_time_build(int year, int month, int day, int hour, int min, int sec) {
time_t RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleTimeBuild", NULL,
	G_TYPE_INT, year,  	G_TYPE_INT, month,  	G_TYPE_INT, day,  	G_TYPE_INT, hour,  	G_TYPE_INT, min,  	G_TYPE_INT, sec,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_escape_text(const char *text, gssize length) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupEscapeText", NULL,
	G_TYPE_STRING, text,  	G_TYPE_INT, length,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_strip_html(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupStripHtml", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_linkify(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupLinkify", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_unescape_text(const char *text) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUnescapeText", NULL,
	G_TYPE_STRING, text,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_unescape_html(const char *html) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUnescapeHtml", NULL,
	G_TYPE_STRING, html,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_slice(const char *str, guint x, guint y) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupSlice", NULL,
	G_TYPE_STRING, str,  	G_TYPE_INT, x,  	G_TYPE_INT, y,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_get_tag_name(const char *tag) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupGetTagName", NULL,
	G_TYPE_STRING, tag,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_unescape_entity(const char *text, const int *length_NULL) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupUnescapeEntity", NULL,
	G_TYPE_STRING, text,  	G_TYPE_INT, 0,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_markup_get_css_property(const char *style, const char *opt) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupGetCssProperty", NULL,
	G_TYPE_STRING, style,  	G_TYPE_STRING, opt,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_markup_is_rtl(const char *html) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleMarkupIsRtl", NULL,
	G_TYPE_STRING, html,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_home_dir(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleHomeDir", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_user_dir(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUserDir", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_util_set_user_dir(const char *dir) {
dbus_g_proxy_call(purple_proxy, "PurpleUtilSetUserDir", NULL,
	G_TYPE_STRING, dir,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

int purple_build_dir(const char *path, int mode) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleBuildDir", NULL,
	G_TYPE_STRING, path,  	G_TYPE_INT, mode,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_util_write_data_to_file(const char *filename, const char *data, gssize size) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleUtilWriteDataToFile", NULL,
	G_TYPE_STRING, filename,  	G_TYPE_STRING, data,  	G_TYPE_INT, size,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_util_write_data_to_file_absolute(const char *filename_full, const char *data, gssize size) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleUtilWriteDataToFileAbsolute", NULL,
	G_TYPE_STRING, filename_full,  	G_TYPE_STRING, data,  	G_TYPE_INT, size,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_program_is_valid(const char *program) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleProgramIsValid", NULL,
	G_TYPE_STRING, program,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_running_gnome(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRunningGnome", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_running_kde(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRunningKde", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_running_osx(void) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleRunningOsx", NULL,
G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_fd_get_ip(int fd) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleFdGetIp", NULL,
	G_TYPE_INT, fd,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_socket_get_family(int fd) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSocketGetFamily", NULL,
	G_TYPE_INT, fd,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_socket_speaks_ipv4(int fd) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleSocketSpeaksIpv4", NULL,
	G_TYPE_INT, fd,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_strequal(const char *left, const char *right) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStrequal", NULL,
	G_TYPE_STRING, left,  	G_TYPE_STRING, right,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_normalize(const PurpleAccount *account, const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleNormalize", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_normalize_nocase(const PurpleAccount *account, const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleNormalizeNocase", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_str_has_prefix(const char *s, const char *p) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStrHasPrefix", NULL,
	G_TYPE_STRING, s,  	G_TYPE_STRING, p,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_str_has_suffix(const char *s, const char *x) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleStrHasSuffix", NULL,
	G_TYPE_STRING, s,  	G_TYPE_STRING, x,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_strdup_withhtml(const char *src) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrdupWithhtml", NULL,
	G_TYPE_STRING, src,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_str_add_cr(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrAddCr", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_strreplace(const char *string, const char *delimiter, const char *replacement) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrreplace", NULL,
	G_TYPE_STRING, string,  	G_TYPE_STRING, delimiter,  	G_TYPE_STRING, replacement,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_utf8_ncr_encode(const char *in) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8NcrEncode", NULL,
	G_TYPE_STRING, in,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_utf8_ncr_decode(const char *in) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8NcrDecode", NULL,
	G_TYPE_STRING, in,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_strcasereplace(const char *string, const char *delimiter, const char *replacement) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrcasereplace", NULL,
	G_TYPE_STRING, string,  	G_TYPE_STRING, delimiter,  	G_TYPE_STRING, replacement,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_strcasestr(const char *haystack, const char *needle) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrcasestr", NULL,
	G_TYPE_STRING, haystack,  	G_TYPE_STRING, needle,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_str_size_to_units(size_t size) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrSizeToUnits", NULL,
	G_TYPE_INT, size,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_str_seconds_to_string(guint sec) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrSecondsToString", NULL,
	G_TYPE_INT, sec,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_str_binary_to_ascii(const unsigned char *binary, guint len) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleStrBinaryToAscii", NULL,
	G_TYPE_STRING, binary,  	G_TYPE_INT, len,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_got_protocol_handler_uri(const char *uri) {
dbus_g_proxy_call(purple_proxy, "PurpleGotProtocolHandlerUri", NULL,
	G_TYPE_STRING, uri,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_util_fetch_url_cancel(const PurpleUtilFetchUrlData *url_data) {
dbus_g_proxy_call(purple_proxy, "PurpleUtilFetchUrlCancel", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(url_data),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_url_decode(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUrlDecode", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_url_encode(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUrlEncode", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_email_is_valid(const char *address) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleEmailIsValid", NULL,
	G_TYPE_STRING, address,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_ip_address_is_valid(const char *ip) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleIpAddressIsValid", NULL,
	G_TYPE_STRING, ip,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_ipv4_address_is_valid(const char *ip) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleIpv4AddressIsValid", NULL,
	G_TYPE_STRING, ip,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_ipv6_address_is_valid(const char *ip) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleIpv6AddressIsValid", NULL,
	G_TYPE_STRING, ip,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

GList* purple_uri_list_extract_uris(const char *uri_list) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleUriListExtractUris", NULL,
	G_TYPE_STRING, uri_list,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

GList* purple_uri_list_extract_filenames(const char *uri_list) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurpleUriListExtractFilenames", NULL,
	G_TYPE_STRING, uri_list,  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

char* purple_uri_escape_for_open(const char *unescaped) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUriEscapeForOpen", NULL,
	G_TYPE_STRING, unescaped,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_utf8_try_convert(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8TryConvert", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_utf8_salvage(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8Salvage", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_utf8_strip_unprintables(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8StripUnprintables", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_gai_strerror(gint errnum) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleGaiStrerror", NULL,
	G_TYPE_INT, errnum,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

int purple_utf8_strcasecmp(const char *a, const char *b) {
int RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8Strcasecmp", NULL,
	G_TYPE_STRING, a,  	G_TYPE_STRING, b,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_utf8_has_word(const char *haystack, const char *needle) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurpleUtf8HasWord", NULL,
	G_TYPE_STRING, haystack,  	G_TYPE_STRING, needle,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_text_strip_mnemonic(const char *in) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleTextStripMnemonic", NULL,
	G_TYPE_STRING, in,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_unescape_filename(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUnescapeFilename", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_escape_filename(const char *str) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleEscapeFilename", NULL,
	G_TYPE_STRING, str,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* _purple_oscar_convert(const char *act, const char *protocol) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleOscarConvert", NULL,
	G_TYPE_STRING, act,  	G_TYPE_STRING, protocol,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_restore_default_signal_handlers(void) {
dbus_g_proxy_call(purple_proxy, "PurpleRestoreDefaultSignalHandlers", NULL,
G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_get_host_name(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleGetHostName", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_uuid_random(void) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleUuidRandom", NULL,
G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void xmlnode_insert_child(const xmlnode *parent, const xmlnode *child) {
dbus_g_proxy_call(purple_proxy, "XmlnodeInsertChild", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(parent),  	G_TYPE_INT, GPOINTER_TO_INT(child),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void xmlnode_insert_data(const xmlnode *node, const char *data, gssize size) {
dbus_g_proxy_call(purple_proxy, "XmlnodeInsertData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, data,  	G_TYPE_INT, size,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* xmlnode_get_data(const xmlnode *node) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeGetData", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* xmlnode_get_data_unescaped(const xmlnode *node) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeGetDataUnescaped", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void xmlnode_set_attrib(const xmlnode *node, const char *attr, const char *value) {
dbus_g_proxy_call(purple_proxy, "XmlnodeSetAttrib", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void xmlnode_set_attrib_with_prefix(const xmlnode *node, const char *attr, const char *prefix, const char *value) {
dbus_g_proxy_call(purple_proxy, "XmlnodeSetAttribWithPrefix", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  	G_TYPE_STRING, prefix,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void xmlnode_set_attrib_with_namespace(const xmlnode *node, const char *attr, const char *xmlns, const char *value) {
dbus_g_proxy_call(purple_proxy, "XmlnodeSetAttribWithNamespace", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  	G_TYPE_STRING, xmlns,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void xmlnode_set_attrib_full(const xmlnode *node, const char *attr, const char *xmlns, const char *prefix, const char *value) {
dbus_g_proxy_call(purple_proxy, "XmlnodeSetAttribFull", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  	G_TYPE_STRING, xmlns,  	G_TYPE_STRING, prefix,  	G_TYPE_STRING, value,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* xmlnode_get_attrib(const xmlnode *node, const char *attr) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeGetAttrib", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* xmlnode_get_attrib_with_namespace(const xmlnode *node, const char *attr, const char *xmlns) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeGetAttribWithNamespace", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  	G_TYPE_STRING, xmlns,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void xmlnode_remove_attrib(const xmlnode *node, const char *attr) {
dbus_g_proxy_call(purple_proxy, "XmlnodeRemoveAttrib", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void xmlnode_remove_attrib_with_namespace(const xmlnode *node, const char *attr, const char *xmlns) {
dbus_g_proxy_call(purple_proxy, "XmlnodeRemoveAttribWithNamespace", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, attr,  	G_TYPE_STRING, xmlns,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void xmlnode_set_namespace(const xmlnode *node, const char *xmlns) {
dbus_g_proxy_call(purple_proxy, "XmlnodeSetNamespace", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, xmlns,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* xmlnode_get_namespace(const xmlnode *node) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeGetNamespace", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void xmlnode_set_prefix(const xmlnode *node, const char *prefix) {
dbus_g_proxy_call(purple_proxy, "XmlnodeSetPrefix", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_STRING, prefix,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* xmlnode_get_prefix(const xmlnode *node) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeGetPrefix", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* xmlnode_to_str(const xmlnode *node, const int *len_NULL) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeToStr", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* xmlnode_to_formatted_str(const xmlnode *node, const int *len_NULL) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "XmlnodeToFormattedStr", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  	G_TYPE_INT, 0,  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void xmlnode_free(const xmlnode *node) {
dbus_g_proxy_call(purple_proxy, "XmlnodeFree", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(node),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleAttentionType* purple_attention_type_new(const char *ulname, const char *name, const char *inc_desc, const char *out_desc) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeNew", NULL,
	G_TYPE_STRING, ulname,  	G_TYPE_STRING, name,  	G_TYPE_STRING, inc_desc,  	G_TYPE_STRING, out_desc,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurpleAttentionType*) GINT_TO_POINTER(RESULT_ID);
}

void purple_attention_type_set_name(const PurpleAttentionType *type, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeSetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_attention_type_set_incoming_desc(const PurpleAttentionType *type, const char *desc) {
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeSetIncomingDesc", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  	G_TYPE_STRING, desc,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_attention_type_set_outgoing_desc(const PurpleAttentionType *type, const char *desc) {
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeSetOutgoingDesc", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  	G_TYPE_STRING, desc,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_attention_type_set_icon_name(const PurpleAttentionType *type, const char *name) {
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeSetIconName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  	G_TYPE_STRING, name,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_attention_type_set_unlocalized_name(const PurpleAttentionType *type, const char *ulname) {
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeSetUnlocalizedName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  	G_TYPE_STRING, ulname,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

char* purple_attention_type_get_name(const PurpleAttentionType *type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeGetName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_attention_type_get_incoming_desc(const PurpleAttentionType *type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeGetIncomingDesc", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_attention_type_get_outgoing_desc(const PurpleAttentionType *type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeGetOutgoingDesc", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_attention_type_get_icon_name(const PurpleAttentionType *type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeGetIconName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

char* purple_attention_type_get_unlocalized_name(const PurpleAttentionType *type) {
char *RESULT = NULL;
dbus_g_proxy_call(purple_proxy, "PurpleAttentionTypeGetUnlocalizedName", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(type),  G_TYPE_INVALID,
	G_TYPE_STRING, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_prpl_got_account_idle(const PurpleAccount *account, gboolean idle, time_t idle_time) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotAccountIdle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, idle,  	G_TYPE_INT, idle_time,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_account_login_time(const PurpleAccount *account, time_t login_time) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotAccountLoginTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, login_time,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_account_actions(const PurpleAccount *account) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotAccountActions", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_user_idle(const PurpleAccount *account, const char *name, gboolean idle, time_t idle_time) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotUserIdle", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, idle,  	G_TYPE_INT, idle_time,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_user_login_time(const PurpleAccount *account, const char *name, time_t login_time) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotUserLoginTime", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_INT, login_time,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_user_status_deactive(const PurpleAccount *account, const char *name, const char *status_id) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotUserStatusDeactive", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, name,  	G_TYPE_STRING, status_id,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_change_account_status(const PurpleAccount *account, const PurpleStatus *old_status, const PurpleStatus *new_status) {
dbus_g_proxy_call(purple_proxy, "PurplePrplChangeAccountStatus", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(old_status),  	G_TYPE_INT, GPOINTER_TO_INT(new_status),  G_TYPE_INVALID,
G_TYPE_INVALID);
}

GList* purple_prpl_get_statuses(const PurpleAccount *account, const PurplePresence *presence) {
GArray *RESULT;
dbus_g_proxy_call(purple_proxy, "PurplePrplGetStatuses", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_INT, GPOINTER_TO_INT(presence),  G_TYPE_INVALID,
	dbus_g_type_get_collection("GArray", G_TYPE_INT), &RESULT,  G_TYPE_INVALID);
return garray_int_to_glist(RESULT);
}

void purple_prpl_send_attention(const PurpleConnection *gc, const char *who, guint type_code) {
dbus_g_proxy_call(purple_proxy, "PurplePrplSendAttention", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_INT, type_code,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_attention(const PurpleConnection *gc, const char *who, guint type_code) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotAttention", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_STRING, who,  	G_TYPE_INT, type_code,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

void purple_prpl_got_attention_in_chat(const PurpleConnection *gc, int id, const char *who, guint type_code) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotAttentionInChat", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(gc),  	G_TYPE_INT, id,  	G_TYPE_STRING, who,  	G_TYPE_INT, type_code,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurpleMediaCaps purple_prpl_get_media_caps(const PurpleAccount *account, const char *who) {
PurpleMediaCaps RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrplGetMediaCaps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, who,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

gboolean purple_prpl_initiate_media(const PurpleAccount *account, const char *who, PurpleMediaSessionType type) {
gboolean RESULT = 0;
dbus_g_proxy_call(purple_proxy, "PurplePrplInitiateMedia", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, who,  	G_TYPE_INT, type,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT,  G_TYPE_INVALID);
return RESULT;
}

void purple_prpl_got_media_caps(const PurpleAccount *account, const char *who) {
dbus_g_proxy_call(purple_proxy, "PurplePrplGotMediaCaps", NULL,
	G_TYPE_INT, GPOINTER_TO_INT(account),  	G_TYPE_STRING, who,  G_TYPE_INVALID,
G_TYPE_INVALID);
}

PurplePlugin* purple_find_prpl(const char *id) {
int RESULT_ID = 0;
dbus_g_proxy_call(purple_proxy, "PurpleFindPrpl", NULL,
	G_TYPE_STRING, id,  G_TYPE_INVALID,
	G_TYPE_INT, &RESULT_ID,  G_TYPE_INVALID);
return (PurplePlugin*) GINT_TO_POINTER(RESULT_ID);
}

